<?php
/**
 * This file belongs to the YIT Plugin Framework.
 *
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 */


if ( !defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

/**
 * Implements the YWQOF_Elementor class.
 *
 * @class   YWQOF_Elementor
 * @package YITH
 * @since   1.2.2
 * @author  YITH
 */
if ( !class_exists( 'YWQOF_Elementor' ) ) {

    /**
     * Class YWQOF_Elementor
     */
    class YWQOF_Elementor{
        /**
         * Single instance of the class
         *
         * @var YWQOF_Elementor
         */

        protected static $instance;

        /**
         * store the order to use in widget previews
         *
         * @var int
         */
        public $order_to_test = 0;

        /**
         * Returns single instance of the class
         *
         * @return YWQOF_Elementor
         */
        public static function get_instance() {
            if ( is_null( self::$instance ) ) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        /**
         * YWQOF_Elementor constructor.
         */
        public function __construct() {
            if ( did_action( 'elementor/loaded' ) ) {
                add_action( 'elementor/elements/categories_registered', array( $this, 'add_elementor_yith_widget_category' ) );
                add_action( 'elementor/widgets/widgets_registered', array( $this, 'elementor_init_widgets' )   );
            }


        }

        /**
         * load frontend styles
         */
        public function load_frontend_styles(){

        }

        /**
         * @param $elements_manager
         */
        public function add_elementor_yith_widget_category( $elements_manager ) {
            $elements_manager->add_category(
                'yith',
                array(
                    'title' => 'YITH',
                    'icon' => 'fa fa-plug',
                )
            );

        }

        /**
         * @throws Exception
         */
        public function elementor_init_widgets(  ) {

            // Include Widget files
            require_once( YITH_YWQOF_PATH . 'includes/third-party/elementor/class-ywqof-forms-widget.php');

            // Register widget
            \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new \YWQOF_Forms_Widget());



        }
    }

}

/**
 * Unique access to instance of YWQOF_Elementor class
 *
 * @return YWQOF_Elementor
 */
function YWQOF_Elementor() {
    return YWQOF_Elementor::get_instance();
}

YWQOF_Elementor();
